@@ -2,9 +2,9 @@
 # SPDX-License-Identifier: (Apache-2.0 AND CC-BY-4.0)
 # Code is Apache-2.0 and docs are CC-BY-4.0
 
-from .driver import Planetmint   # noqa
+from .driver import Planetmint  # noqa
 
 
-__author__ = 'Planetmint'
-__email__ = 'devs@planetmint.com'
-__version__ = '0.6.2'
+__author__ = "Planetmint"
+__email__ = "devs@planetmint.com"
+__version__ = "0.11.0"
