@@ -13,7 +13,7 @@ from .common.transaction import (
     Input,
     Transaction,
     TransactionLink,
-    _fulfillment_from_details
+    _fulfillment_from_details,
 )
 from .common.exceptions import KeypairMismatchException
 
@@ -28,32 +28,25 @@ logger = logging.getLogger(__name__)
 
 
 @singledispatch
-def _prepare_transaction(operation,
-                         signers=None,
-                         recipients=None,
-                         asset=None,
-                         metadata=None,
-                         inputs=None):
-    raise PlanetmintException((
-        'Unsupported operation: {}. '
-        'Only "CREATE" and "TRANSFER" are supported.'.format(operation)))
+def _prepare_transaction(operation, signers=None, recipients=None, asset=None, metadata=None, inputs=None):
+    raise PlanetmintException(
+        ("Unsupported operation: {}. " 'Only "CREATE" and "TRANSFER" are supported.'.format(operation))
+    )
 
 
 @_prepare_transaction.register(CreateOperation)
 def _prepare_create_transaction_dispatcher(operation, **kwargs):
-    del kwargs['inputs']
+    del kwargs["inputs"]
     return prepare_create_transaction(**kwargs)
 
 
 @_prepare_transaction.register(TransferOperation)
 def _prepare_transfer_transaction_dispatcher(operation, **kwargs):
-    del kwargs['signers']
+    del kwargs["signers"]
     return prepare_transfer_transaction(**kwargs)
 
 
-def prepare_transaction(*, operation='CREATE', signers=None,
-                        recipients=None, asset=None, metadata=None,
-                        inputs=None):
+def prepare_transaction(*, operation="CREATE", signers=None, recipients=None, asset=None, metadata=None, inputs=None):
     """Prepares a transaction payload, ready to be fulfilled. Depending on
     the value of ``operation``, simply dispatches to either
     :func:`~.prepare_create_transaction` or
@@ -133,11 +126,7 @@ def prepare_transaction(*, operation='CREATE', signers=None,
     )
 
 
-def prepare_create_transaction(*,
-                               signers,
-                               recipients=None,
-                               asset=None,
-                               metadata=None):
+def prepare_create_transaction(*, signers, recipients=None, asset=None, metadata=None):
     """Prepares a ``"CREATE"`` transaction payload, ready to be
     fulfilled.
 
@@ -193,16 +182,12 @@ def prepare_create_transaction(*,
         signers,
         recipients,
         metadata=metadata,
-        asset=asset['data'] if asset else None,
+        asset=asset,
     )
     return transaction.to_dict()
 
 
-def prepare_transfer_transaction(*,
-                                 inputs,
-                                 recipients,
-                                 asset,
-                                 metadata=None):
+def prepare_transfer_transaction(*, inputs, recipients, asset, metadata=None):
     """Prepares a ``"TRANSFER"`` transaction payload, ready to be
     fulfilled.
 
@@ -292,7 +277,7 @@ def prepare_transfer_transaction(*,
 
     """
     if not isinstance(inputs, (list, tuple)):
-        inputs = (inputs, )
+        inputs = (inputs,)
     if not isinstance(recipients, (list, tuple)):
         recipients = [([recipients], 1)]
 
@@ -302,18 +287,21 @@ def prepare_transfer_transaction(*,
         recipients = [(list(recipients), 1)]
 
     fulfillments = [
-        Input(_fulfillment_from_details(input_['fulfillment']),
-              input_['owners_before'],
-              fulfills=TransactionLink(
-                  txid=input_['fulfills']['transaction_id'],
-                  output=input_['fulfills']['output_index']))
+        Input(
+            _fulfillment_from_details(input_["fulfillment"]),
+            input_["owners_before"],
+            fulfills=TransactionLink(
+                txid=input_["fulfills"]["transaction_id"],
+                output=input_["fulfills"]["output_index"],
+            ),
+        )
         for input_ in inputs
     ]
 
     transaction = Transaction.transfer(
         fulfillments,
         recipients,
-        asset_id=asset['id'],
+        asset_id=asset["id"],
         metadata=metadata,
     )
     return transaction.to_dict()
@@ -349,7 +337,7 @@ def fulfill_transaction(transaction, *, private_keys):
     try:
         signed_transaction = transaction_obj.sign(private_keys)
     except KeypairMismatchException as exc:
-        raise MissingPrivateKeyError('A private key is missing!') from exc
+        raise MissingPrivateKeyError("A private key is missing!") from exc
 
     return signed_transaction.to_dict()
 
@@ -367,6 +355,4 @@ def fulfill_with_signing_delegation(transaction, signing_callback):
         dict: The fulfilled transaction payload, ready to be sent to a
             Planetmint federation.
     """
-    return (Transaction.from_dict(transaction)
-            .delegate_signing(signing_callback)
-            .to_dict())
+    return Transaction.from_dict(transaction).delegate_signing(signing_callback).to_dict()
